@@ -28,21 +28,25 @@
 #'
 #' @param data a \code{matrix} or \code{data.frame} that consists of
 #'   numerically ordered data, with missing data coded as \code{NA}
-#' @param model number of classes to fit, or alternatively a \code{\link{mirt.model}} definition. Note that
-#'   when using a \code{\link{mirt.model}} input in conjunction with the \code{customTheta} input defined below,
-#'   the order with which the syntax factors are defined will be associated with the columns in the
-#'   \code{customTheta} input
+#' @param model number of mutually exclusive classes to fit, or alternatively a more specific
+#'   \code{\link{mirt.model}} definition (which reflects the so-called Q-matrix).
+#'   Note that when using a \code{\link{mirt.model}},
+#'   the order with which the syntax factors/attributes are defined are associated with the
+#'   columns in the \code{customTheta} input
 #' @param method estimation method. Can be 'EM' or 'BL' (see \code{\link{mirt}} for more details)
 #' @param optimizer optimizer used for the M-step, set to \code{'nlminb'} by default.
 #'   See \code{\link{mirt}} for more details
 #' @param group a factor variable indicating group membership used for multiple group analyses
+#' @param itemtype a vector indicating the itemtype associated with each item.
+#'   For discrete models this is limited to only 'lca' or items defined using a
+#'   \code{\link{createItem}} definition
 #' @param GenRandomPars logical; use random starting values
-#' @param customTheta input passed to \code{technical = list(customTheta = ...)}, but is included directly
-#'   in this function for convenience. This input is most interesting for discrete latent models
-#'   because it allows for customized patterns of latent class effects.
-#'   The default builds the pattern \code{customTheta = diag(model)},
+#' @param customTheta input passed to \code{technical = list(customTheta = ...)}, but is included
+#'   directly in this function for convenience. This input is most interesting for discrete latent models
+#'   because it allows customized patterns of latent class effects (defines the possible combinations
+#'   of the latent attribute profile). The default builds the pattern \code{customTheta = diag(model)},
 #'   which is the typical pattern for the traditional
-#'   latent class analysis (whereby classes are completely distinct)
+#'   latent class analysis whereby classes are completely distinct
 #' @param nruns a numeric value indicating how many times the model should be fit to the data
 #'   when using random starting values. If greater than 1, \code{GenRandomPars} is set to true
 #'   by default
@@ -230,7 +234,7 @@
 #'                      CONSTRAIN = (1-16, a1), (1-16, a2), (1-16, a3), (1-16, a4), (1-16, a5),
 #'                        (17-32, a6), (17-32, a7), (17-32, a8), (17-32, a9), (17-32, a10)')
 #'
-#' theta <- diag(10)
+#' theta <- diag(10) # defined explicitly. Otherwise, this profile is assumed
 #' mod <- mdirt(dat, model, customTheta = theta)
 #' coef(mod, simplify=TRUE)
 #' summary(mod)
@@ -253,15 +257,19 @@
 #'
 #' }
 mdirt <- function(data, model, customTheta = NULL, nruns = 1, method = 'EM',
-                  covdata = NULL, formula = NULL,
+                  covdata = NULL, formula = NULL, itemtype = 'lca',
                   optimizer = 'nlminb', return_max = TRUE, group = NULL, GenRandomPars = FALSE,
                   verbose = TRUE, pars = NULL, technical = list(), ...)
 {
     Call <- match.call()
+    dots <- list(...)
     latent.regression <- latentRegression_obj(data=data, covdata=covdata, formula=formula,
                                               empiricalhist=FALSE, method=method)
     technical$customTheta <- customTheta
-    itemtype <- 'lca'
+    valid_itemtype <- 'lca'
+    if(!is.null(dots$customItems))
+        valid_itemtype <- c(valid_itemtype, names(dots$customItems))
+    stopifnot(all(itemtype %in% valid_itemtype))
     stopifnot(method %in% c('EM', 'BL'))
     if(nruns > 1) GenRandomPars <- TRUE
     if(is.null(group)) group <- rep('all', nrow(data))
