@@ -46,7 +46,7 @@ draw.thetas <- function(theta0, pars, fulldata, itemloc, cand.t.var, prior.t.var
             return(theta1)
         }
         diff <- total_1 - total_0
-        accept <- unif < exp(diff)
+        accept <- log(unif) < diff
         theta1[!accept, ] <- theta0[!accept, ]
         total_1[!accept] <- total_0[!accept]
         log.lik <- sum(total_1)
@@ -636,6 +636,10 @@ expbeta_sv <- function(val1, val2){
 
 UpdateParameters <- function(PrepList, model, groupNames){
     if(!is.numeric(model)){
+        nitems <- length(PrepList[[1L]]$pars) - 1L
+        model$x[,"Parameters"] <- gsub("\\(GROUP,",
+                                       replacement = sprintf("(%i,", nitems + 1L),
+                                       model$x[,"Parameters"])
         groupNames <- as.character(groupNames)
         pars <- vector('list', length(PrepList))
         for(g in seq_len(length(PrepList)))
@@ -670,7 +674,7 @@ UpdateParameters <- function(PrepList, model, groupNames){
                         len <- length(esplit[[i]])
                         tmp <- lapply(tmp, function(x, which, val){
                             if(which %in% c('g', 'u')) val <- qlogis(val)
-                            x@par[names(x@parnum) == which] <- val
+                            x@par[names(x@est) == which] <- val
                             x
                         }, which=esplit[[i]][len-1L], val = as.numeric(esplit[[i]][len]))
                         pars[[gpick]][picks[[i]]] <- tmp
@@ -700,7 +704,7 @@ UpdateParameters <- function(PrepList, model, groupNames){
                         tmp <- pars[[gpick]][picks[[i]]]
                         len <- length(esplit[[i]])
                         tmp <- lapply(tmp, function(x, which){
-                            x@est[names(x@parnum) == which] <- FALSE
+                            x@est[names(x@est) == which] <- FALSE
                             x
                         }, which=esplit[[i]][len])
                         pars[[gpick]][picks[[i]]] <- tmp
@@ -730,7 +734,7 @@ UpdateParameters <- function(PrepList, model, groupNames){
                         tmp <- pars[[gpick]][picks[[i]]]
                         len <- length(esplit[[i]])
                         tmp <- lapply(tmp, function(x, which){
-                            x@est[names(x@parnum) == which] <- TRUE
+                            x@est[names(x@est) == which] <- TRUE
                             x
                         }, which=esplit[[i]][len])
                         pars[[gpick]][picks[[i]]] <- tmp
@@ -761,7 +765,7 @@ UpdateParameters <- function(PrepList, model, groupNames){
                         len <- length(esplit[[i]])
                         tmp <- lapply(tmp, function(x, which, val){
                             if(which %in% c('g', 'u')) val <- qlogis(val)
-                            x@lbound[names(x@parnum) == which] <- val
+                            x@lbound[names(x@est) == which] <- val
                             x
                         }, which=esplit[[i]][len-1L], val = as.numeric(esplit[[i]][len]))
                         pars[[gpick]][picks[[i]]] <- tmp
@@ -792,7 +796,7 @@ UpdateParameters <- function(PrepList, model, groupNames){
                         len <- length(esplit[[i]])
                         tmp <- lapply(tmp, function(x, which, val){
                             if(which %in% c('g', 'u')) val <- qlogis(val)
-                            x@ubound[names(x@parnum) == which] <- val
+                            x@ubound[names(x@est) == which] <- val
                             x
                         }, which=esplit[[i]][len-1L], val = as.numeric(esplit[[i]][len]))
                         pars[[gpick]][picks[[i]]] <- tmp
@@ -919,7 +923,7 @@ ReturnPars <- function(PrepList, itemnames, random, lrPars, lr.random = NULL, MG
             if(i <= length(itemnames))
                 item <- c(item, rep(itemnames[i], length(tmpgroup[[i]]@parnum)))
             class <- c(class, rep(class(tmpgroup[[i]]), length(tmpgroup[[i]]@parnum)))
-            parname <- c(parname, names(tmpgroup[[i]]@est))
+            parname <- c(parname, tmpgroup[[i]]@parnames)
             parnum <- c(parnum, tmpgroup[[i]]@parnum)
             par <- c(par, tmpgroup[[i]]@par)
             est <- c(est, tmpgroup[[i]]@est)
@@ -935,7 +939,7 @@ ReturnPars <- function(PrepList, itemnames, random, lrPars, lr.random = NULL, MG
         item <- c(item, rep('GROUP', length(tmpgroup[[i]]@parnum)))
     }
     for(i in seq_len(length(random))){
-        parname <- c(parname, names(random[[i]]@est))
+        parname <- c(parname, random[[i]]@parnames)
         parnum <- c(parnum, random[[i]]@parnum)
         par <- c(par, random[[i]]@par)
         est <- c(est, random[[i]]@est)
@@ -951,7 +955,7 @@ ReturnPars <- function(PrepList, itemnames, random, lrPars, lr.random = NULL, MG
         item <- c(item, rep('RANDOM', length(random[[i]]@parnum)))
     }
     if(length(lrPars)){
-        parname <- c(parname, names(lrPars@est))
+        parname <- c(parname, lrPars@parnames)
         parnum <- c(parnum, lrPars@parnum)
         par <- c(par, lrPars@par)
         est <- c(est, lrPars@est)
@@ -967,7 +971,7 @@ ReturnPars <- function(PrepList, itemnames, random, lrPars, lr.random = NULL, MG
         item <- c(item, rep('BETA', length(lrPars@parnum)))
     }
     for(i in seq_len(length(lr.random))){
-        parname <- c(parname, names(lr.random[[i]]@est))
+        parname <- c(parname, lr.random[[i]]@parnames)
         parnum <- c(parnum, lr.random[[i]]@parnum)
         par <- c(par, lr.random[[i]]@par)
         est <- c(est, lr.random[[i]]@est)
@@ -1529,6 +1533,7 @@ make.randomdesign <- function(random, longdata, covnames, itemdesign, N, LR=FALS
         ret[[i]] <- new('RandomPars',
                         par=par,
                         est=est,
+                        parnames=names(est),
                         SEpar=rep(NaN,length(par)),
                         ndim=ndim,
                         lbound=lbound,
@@ -1589,6 +1594,7 @@ make.lrdesign <- function(df, formula, factorNames, EM=FALSE, TOL){
                par=par,
                SEpar=rep(NaN,length(par)),
                est=est,
+               parnames=names(est),
                beta=beta,
                sigma=sigma,
                nfact=nfact,
