@@ -5,7 +5,7 @@ test_that('exploratory mods', {
     fulldata <- expand.table(LSAT7)
     onefact <- mirt(fulldata, 1, verbose = FALSE, SE.type='MHRM', SE=TRUE)
     expect_is(onefact, 'SingleGroupClass')
-    cfs <- as.numeric(do.call(c, coef(onefact, digits=4)))
+    cfs <- as.numeric(do.call(c, coef(onefact)))
     expect_equal(cfs, c(0.9879,0.6579,1.3179,1.8561,1.6074,2.1048,0,NA,NA,1,NA,NA,1.0809,0.7741,1.3877,0.808,0.6389,0.9771,0,NA,NA,1,NA,NA,1.7058,1.1881,2.2235,1.8042,1.4628,2.1457,0,NA,NA,1,NA,NA,0.7652,0.51,1.0203,0.486,0.3402,0.6318,0,NA,NA,1,NA,NA,0.7358,0.4549,1.0167,1.8545,1.6328,2.0762,0,NA,NA,1,NA,NA,0,NA,NA,1,NA,NA),
                  tolerance = 1e-2)
     names <- wald(onefact)
@@ -23,7 +23,7 @@ test_that('exploratory mods', {
     expect_is(fitonefact, 'data.frame')
     expect_equal(fitonefact$M2, 11.93769, tolerance = 1e-2)
     twofact <- mirt(fulldata, 2, verbose = FALSE, draws = 10, method = 'MHRM')
-    cfs <- as.numeric(do.call(c, coef(twofact, digits=4, verbose = FALSE)))
+    cfs <- as.numeric(do.call(c, coef(twofact, verbose = FALSE)))
     expect_equal(cfs, c(-1.4378,0.2262,2.1215,0,1,-1.0463,-1.439,1.0058,0,1,-1.291,-0.7683,1.6927,0,1,-0.8431,-0.0161,0.4919,0,1,-0.7941,0,1.8772,0,1,0,0,1,0,1),
                  tolerance = 1e-2)
     expect_is(twofact, 'SingleGroupClass')
@@ -36,7 +36,7 @@ test_that('exploratory mods', {
     fulldata[1,1] <- fulldata[2,2] <- NA
     onefactmissing <- mirt(fulldata, 1, verbose = FALSE, draws = 10, method = 'MHRM')
     expect_is(onefactmissing, 'SingleGroupClass')
-    cfs <- as.numeric(do.call(c, coef(onefactmissing, digits=4, verbose = FALSE)))
+    cfs <- as.numeric(do.call(c, coef(onefactmissing, verbose = FALSE)))
     expect_equal(cfs, c(0.969,1.8464,0,1,1.0833,0.806,0,1,1.6824,1.7834,0,1,0.7595,0.4829,0,1,0.7681,1.8658,0,1,0,1),
                  tolerance = 1e-2)
 
