@@ -51,22 +51,19 @@ test_that('mixed dich', {
     expect_equal(cfs, c(0.8023,1.5944,1,-1.3592,0,1,1.3988,2.9293,1,-2.4552,0,1,2.4305,4.4838,1,-3.1509,0,1,0.307,0.7794,1,-0.2878,0,1,1.4845,3.0533,1,-0.5464,0,1,1.2012,3.0349,1,-1.6528,0,1,0.9915,1.9697,1,-1.513,0,1,1.4304,2.6556,1,-2.4036,0,1,0.8535,2.0584,1,-1.8064,0,1,0.8374,2.3511,1,1.6148,0,1,0,0.1489),
                  tolerance = 1e-2)
 
-    mod_items <- try(mixedmirt(data, covdata, model, fixed = ~ 1, SE=FALSE, random = ~ 1|items,
-                       verbose = FALSE, draws = 1), TRUE)
-    if(!is(mod_items, 'try-error')){
-        cfs <- c(coef(mod_items)[['GroupPars']], coef(mod_items)[['items']])
-        expect_equal(cfs[1:3], c(0.000, 1.083, 1.125), tolerance = 1e-2)
-    }
+    mod_items <- mixedmirt(data, covdata, model, fixed = ~ 1, SE=FALSE, random = ~ 1|items,
+                       verbose = FALSE, draws = 1)
+    cfs <- c(coef(mod_items)[['GroupPars']], coef(mod_items)[['items']])
+    expect_equal(cfs[1:3], c(0.000, 1.083, 1.125), tolerance = 1e-2)
 
     mod_items.group <- try(mixedmirt(data, covdata, model, fixed = ~ 1, SE=FALSE, random = ~ 1|items:group,
                            verbose = FALSE, draws = 1), TRUE)
-    if(!is(mod_items.group, 'try-error')){
-        cfs <- c(coef(mod_items.group)[['GroupPars']], coef(mod_items.group)[['items:group']])
-        expect_equal(cfs[1:3], c(0.000, 0.1431, 2.2536), tolerance = 1e-3)
-        set.seed(1)
-        bs <- boot.mirt(mod_items.group, R=2)
-        expect_is(bs, 'boot')
-    }
+    cfs <- c(coef(mod_items.group)[['GroupPars']], coef(mod_items.group)[['items:group']])
+    expect_equal(cfs[1:3], c(0.000, 0.1431, 2.2536), tolerance = 1e-3)
+    set.seed(1)
+    bs <- boot.mirt(mod_items.group, R=2)
+    expect_is(bs, 'boot')
+
 
     #model using 2PL items instead of only Rasch, and with missing data
     data[1,1] <- covdata[1,2] <- NA
@@ -81,13 +78,11 @@ test_that('mixed dich', {
     covdata$group <- factor(rep(paste0('G',1:50), each = N/50))
     rmod1 <- try(mixedmirt(data, covdata, 1, fixed = ~ 0 + items, random = ~ 1|group,
                                         draws = 1, verbose = FALSE), TRUE)
-    if(!is(rmod1, 'try-error')){
-        expect_is(rmod1, 'MixedClass')
-        expect_equal(extract.mirt(rmod1, 'df'), 1011)
-        cfs <- as.numeric(do.call(c, coef(rmod1)))
-        expect_equal(cfs[124:129], c(0.06756121, 0.05018307, 0.08493935, 1.13460966, 0.66202405, 1.60719526),
-                     tolerance = 1e-2)
-    }
+    expect_is(rmod1, 'MixedClass')
+    expect_equal(extract.mirt(rmod1, 'df'), 1011)
+    cfs <- as.numeric(do.call(c, coef(rmod1)))
+    expect_equal(cfs[124:129], c(0.06756121, 0.05018307, 0.08493935, 1.13460966, 0.66202405, 1.60719526),
+                 tolerance = 1e-2)
 
     #polytomous
     covdat <- data.frame(group = rep(c('m', 'f'), nrow(Science)/2))
@@ -118,16 +113,15 @@ test_that('mixed dich', {
     covdat$group <- factor(rep(paste0('G',1:20), length.out = nrow(Science)))
     rmod1 <- try(mixedmirt(Science, covdat, model=model, draws=10, random = ~ 1|group,
                        itemtype = 'graded', verbose = FALSE, SE=FALSE), TRUE)
-    if(!is(rmod1, 'try-error')){
-        expect_is(rmod1, 'MixedClass')
-        expect_equal(extract.mirt(rmod1, 'df'), 238)
-        cfs <- as.numeric(na.omit(do.call(c, coef(rmod1))))
-        expect_equal(cfs, c(1.062578,4.895614,2.661662,-1.479457,1.195101,2.907836,0.897937,-2.253751,2.178545,5.083139,2.151222,-1.918151,1.08017,3.345869,0.9912499,-1.68683,0,1,0.006179096),
-                     tolerance = 1e-4)
-        re <- randef(rmod1, ndraws=100)
-        expect_is(re, 'list')
-        expect_equal(length(re), 2)
-    }
+    expect_is(rmod1, 'MixedClass')
+    expect_equal(extract.mirt(rmod1, 'df'), 238)
+    cfs <- as.numeric(na.omit(do.call(c, coef(rmod1))))
+    expect_equal(cfs, c(1.062578,4.895614,2.661662,-1.479457,1.195101,2.907836,0.897937,-2.253751,2.178545,5.083139,2.151222,-1.918151,1.08017,3.345869,0.9912499,-1.68683,0,1,0.006179096),
+                 tolerance = 1e-4)
+    re <- randef(rmod1, ndraws=100)
+    expect_is(re, 'list')
+    expect_equal(length(re), 2)
+
 
     ## latent regression
     set.seed(1234)
@@ -161,16 +155,12 @@ test_that('mixed dich', {
     covdata$cut <- factor(cut(Theta, breaks=2))
     mod <- try(mixedmirt(dat, covdata = covdata, 1, fixed = ~ 0 + items, SE=FALSE,
                      random = ~ -1 + cut|group, verbose=FALSE, draws=1), TRUE)
-    if(!is(mod, 'try-error')){
-        so <- summary(mod, verbose=FALSE)
-        expect_equal(as.numeric(diag(so$random$group)), c(0.6155525, 0.4089267), tolerance = 1e-4)
-    }
+    so <- summary(mod, verbose=FALSE)
+    expect_equal(as.numeric(diag(so$random$group)), c(0.6155525, 0.4089267), tolerance = 1e-4)
 
     mod <- try(mixedmirt(dat, covdata = covdata, 1, fixed = ~ 0 + items, SE=FALSE,
                      random = ~ -1 + theta|group, verbose=FALSE, draws=1), TRUE)
-    if(!is(mod, 'try-error')){
-        so <- summary(mod, verbose=FALSE)
-        expect_equal(as.numeric(diag(so$random$group)), c(0.2255360, 0.4568764), tolerance = 1e-4)
-    }
+    so <- summary(mod, verbose=FALSE)
+    expect_equal(as.numeric(diag(so$random$group)), c(0.2255360, 0.4568764), tolerance = 1e-4)
 
 })
